/**
  Generated Main Source File

  Company:
    Microchip Technology Inc.

  File Name:
    main.c

  Summary:
    This is the main file generated using MPLAB(c) Code Configurator

  Description:
    This header file provides implementations for driver APIs for all modules selected in the GUI.
    Generation Information :
        Product Revision  :  MPLAB(c) Code Configurator - 3.16
        Device            :  PIC16F1769
        Driver Version    :  2.00
    The generated drivers are tested against the following:
        Compiler          :  XC8 1.35
        MPLAB             :  MPLAB X 3.20
*/

/*
    (c) 2016 Microchip Technology Inc. and its subsidiaries. You may use this
    software and any derivatives exclusively with Microchip products.

    THIS SOFTWARE IS SUPPLIED BY MICROCHIP "AS IS". NO WARRANTIES, WHETHER
    EXPRESS, IMPLIED OR STATUTORY, APPLY TO THIS SOFTWARE, INCLUDING ANY IMPLIED
    WARRANTIES OF NON-INFRINGEMENT, MERCHANTABILITY, AND FITNESS FOR A
    PARTICULAR PURPOSE, OR ITS INTERACTION WITH MICROCHIP PRODUCTS, COMBINATION
    WITH ANY OTHER PRODUCTS, OR USE IN ANY APPLICATION.

    IN NO EVENT WILL MICROCHIP BE LIABLE FOR ANY INDIRECT, SPECIAL, PUNITIVE,
    INCIDENTAL OR CONSEQUENTIAL LOSS, DAMAGE, COST OR EXPENSE OF ANY KIND
    WHATSOEVER RELATED TO THE SOFTWARE, HOWEVER CAUSED, EVEN IF MICROCHIP HAS
    BEEN ADVISED OF THE POSSIBILITY OR THE DAMAGES ARE FORESEEABLE. TO THE
    FULLEST EXTENT ALLOWED BY LAW, MICROCHIP'S TOTAL LIABILITY ON ALL CLAIMS IN
    ANY WAY RELATED TO THIS SOFTWARE WILL NOT EXCEED THE AMOUNT OF FEES, IF ANY,
    THAT YOU HAVE PAID DIRECTLY TO MICROCHIP FOR THIS SOFTWARE.

    MICROCHIP PROVIDES THIS SOFTWARE CONDITIONALLY UPON YOUR ACCEPTANCE OF THESE
    TERMS.
*/

#define Def_OverTemp_Protection 0   //1=Enable

#include "mcc.h"
#include "globals.h"
#include "task_scheduler.h"

//For Simple Softstart
uint8_t     TaskCounter=0, loopct=0;
uint16_t    DACValue = 5;

/*
                         Main application
 */
void main(void)
{
  // initialize the device
  SYSTEM_Initialize();

  InitFaultHandler();
  InitConverter();
  
  // Measure Brightness Index Number (BIN) resistor and set associated forward currents
  GetBIN();

  
  //Interrupts must be enabled by hand
  GIE = 1;
  PEIE = 1;

  InitUARTsend();
  OPA1CONbits.EN = 1;
  PRG1_StartRampGeneration();
  
  TMR2_Start();
  
  while (1)
  {
    //---------------------------Task scheduler---------------------------------    
    TaskCounter++;
    switch (TaskCounter)
    {
      //UART Rec handler
      case 1:
        task_RecUart();
      break;
      //UART Send handler
      case 2:
        UARTsend.SendTaskCounter++;
        if (UARTsend.SendTaskCounter > 10)
        {  
          task_SendUart();
          UARTsend.SendTaskCounter = 0;
        }
      break;
      //Vout handler
      case 3:
        task_CheckOutputVoltage(); 
      break;
      //Vin handler
      case 4:
        task_CheckInputUnderVoltage(); 
        task_CheckInputOverVoltage();
      break;
      //Dimming handler
      case 5:
        task_SetDimmingDutyRatio(); 
      break;
      //UART Rec handler
      case 6:
        task_RecUart();
      break;
      //Fault handler
      case 7:
        FaultHandler();
      break;
      //Temperature handler
      case 8:
#if (Def_OverTemp_Protection == 1)
        task_CheckTemperatureWarning();
        task_CheckTemperatureProtection(); 
#endif
      break;
      //xx handler
      case 9:
          if(DACValue < 0x1E) {
            loopct++;
            if(loopct == 30) {
                DAC1_Load10bitInputData(++DACValue);
                loopct = 0;
            }
          }
        task_Idle();
      break;
      //xx handler
      case 10:
        task_Idle();
        TaskCounter = 0;
      break;
      //Default
      default:
        NOP();
      break;
    }   
    //---------------------------Task scheduler---------------------------------    
 
    // Wait for next task window 
    while (!INTCONbits.T0IF);
    INTCONbits.T0IF = 0;
    TMR0_Reload(); //time=100us
    
    RC6 ^= 1;
  }//while1 end
}
