/*
    (c) 2016 Microchip Technology Inc. and its subsidiaries. You may use this
    software and any derivatives exclusively with Microchip products.

    THIS SOFTWARE IS SUPPLIED BY MICROCHIP "AS IS". NO WARRANTIES, WHETHER
    EXPRESS, IMPLIED OR STATUTORY, APPLY TO THIS SOFTWARE, INCLUDING ANY IMPLIED
    WARRANTIES OF NON-INFRINGEMENT, MERCHANTABILITY, AND FITNESS FOR A
    PARTICULAR PURPOSE, OR ITS INTERACTION WITH MICROCHIP PRODUCTS, COMBINATION
    WITH ANY OTHER PRODUCTS, OR USE IN ANY APPLICATION.

    IN NO EVENT WILL MICROCHIP BE LIABLE FOR ANY INDIRECT, SPECIAL, PUNITIVE,
    INCIDENTAL OR CONSEQUENTIAL LOSS, DAMAGE, COST OR EXPENSE OF ANY KIND
    WHATSOEVER RELATED TO THE SOFTWARE, HOWEVER CAUSED, EVEN IF MICROCHIP HAS
    BEEN ADVISED OF THE POSSIBILITY OR THE DAMAGES ARE FORESEEABLE. TO THE
    FULLEST EXTENT ALLOWED BY LAW, MICROCHIP'S TOTAL LIABILITY ON ALL CLAIMS IN
    ANY WAY RELATED TO THIS SOFTWARE WILL NOT EXCEED THE AMOUNT OF FEES, IF ANY,
    THAT YOU HAVE PAID DIRECTLY TO MICROCHIP FOR THIS SOFTWARE.

    MICROCHIP PROVIDES THIS SOFTWARE CONDITIONALLY UPON YOUR ACCEPTANCE OF THESE
    TERMS.
*/

// This is a guard condition so that contents of this file are not included
// more than once.  
#ifndef _TABLE_BIN_CLASSES_8BIT_H_
#define	_TABLE_BIN_CLASSES_8BIT_H_

/*@@tab_bin.h
 * *****************************************************************************
 * Summary:
 * Provides a scaled lookup table for binning
 *
 * Description:
 * This look-up table has been created for a series of binning classes, identified by using
 * a binning resistor on the LED load forming a voltage divider with the 10k reference resistor 
 * on the driver board. 
 * The bias voltage of this voltage divider is VDD of the controller.
 * Each index of this look-up table provides a Brightness Index Number (BIN) for each 
 * LED type supported. 
 * 
 * This LED type ID is used to select reference currents and other specific data for each
 * type from other tables
 * 
 * To identify a binning class, the 4 LSB of the ADC result buffer are masked out
 * before the value is compared with the table:
 * 
 *   (ADCBUF & bin_mask) = tab_bin[n];	//n is the BIN from 0 to 16
 * 
 * If the bias voltage is measured directly (BIN = 17) a broken/open connection
 * between LED driver board and LED load is assumed.
 *
 * *****************************************************************************
 */


#include <stdint.h>

extern const uint16_t bin_class_feedback_mask;
extern const uint16_t bin_class_feedback_lbound;
extern const uint16_t bin_class_feedback_ubound;
extern const uint8_t  bin_class_nominal;

extern const uint16_t tab_bin_class_feedback[];
extern const uint16_t tab_bin[];
extern const uint16_t tab_vfwd_max[];

#endif	/* _TABLE_BIN_CLASSES_8BIT_H_ */
