/*
    (c) 2016 Microchip Technology Inc. and its subsidiaries. You may use this
    software and any derivatives exclusively with Microchip products.

    THIS SOFTWARE IS SUPPLIED BY MICROCHIP "AS IS". NO WARRANTIES, WHETHER
    EXPRESS, IMPLIED OR STATUTORY, APPLY TO THIS SOFTWARE, INCLUDING ANY IMPLIED
    WARRANTIES OF NON-INFRINGEMENT, MERCHANTABILITY, AND FITNESS FOR A
    PARTICULAR PURPOSE, OR ITS INTERACTION WITH MICROCHIP PRODUCTS, COMBINATION
    WITH ANY OTHER PRODUCTS, OR USE IN ANY APPLICATION.

    IN NO EVENT WILL MICROCHIP BE LIABLE FOR ANY INDIRECT, SPECIAL, PUNITIVE,
    INCIDENTAL OR CONSEQUENTIAL LOSS, DAMAGE, COST OR EXPENSE OF ANY KIND
    WHATSOEVER RELATED TO THE SOFTWARE, HOWEVER CAUSED, EVEN IF MICROCHIP HAS
    BEEN ADVISED OF THE POSSIBILITY OR THE DAMAGES ARE FORESEEABLE. TO THE
    FULLEST EXTENT ALLOWED BY LAW, MICROCHIP'S TOTAL LIABILITY ON ALL CLAIMS IN
    ANY WAY RELATED TO THIS SOFTWARE WILL NOT EXCEED THE AMOUNT OF FEES, IF ANY,
    THAT YOU HAVE PAID DIRECTLY TO MICROCHIP FOR THIS SOFTWARE.

    MICROCHIP PROVIDES THIS SOFTWARE CONDITIONALLY UPON YOUR ACCEPTANCE OF THESE
    TERMS.
*/


#include <stdint.h>
#include "globals.h"

// ======================================================================================================
// Supported LED Types BIN classes and associated forward currents
// ======================================================================================================
#define BIN_KX_ADCValue ((uint16_t)((2200 /(2200+10000)) *1023))    //2k20
#define BIN_KY_ADCValue ((uint16_t)((6800 /(2200+10000)) *1023))    //6k80
#define BIN_KZ_ADCValue ((uint16_t)((15000/(15000+10000))*1023))    //15k0
#define BIN_LX_ADCValue ((uint16_t)((47000/(47000+10000))*1023))    //47k0
#define BIN_LY_ADCValue ((uint16_t)((270000/(270000+10000))*1023))  //270k

const uint16_t tab_bin_class_feedback[5] = //ADC values
{
	184,	// BIN resistor = >2k2 => LUW_W5SM_KX
	414,	// BIN resistor = >6k8 => LUW_W5SM_KY
	613,	// BIN resistor = >15k => LUW_W5SM_KZ
	843,	// BIN resistor = >47k => LUW_W5SM_LX  (=> default)
	986		// BIN resistor = >270k => LUW_W5SM_LY
};

const uint16_t bin_class_feedback_mask = 0xFFF0;

// Brightness INdex Numbers and related forward current ratios
// (These pre-compiler macros calculate the set-values for the internal DAC directly)

#define LUW_W5SM_KX		(uint16_t)(1.581699 * (LEDForwardCurrent/DACREF2IfwdScaler))
#define LUW_W5SM_KY		(uint16_t)(1.351955 * (LEDForwardCurrent/DACREF2IfwdScaler))
#define LUW_W5SM_KZ		(uint16_t)(1.157895 * (LEDForwardCurrent/DACREF2IfwdScaler))
#define LUW_W5SM_LX		(uint16_t)(1.000000 * (LEDForwardCurrent/DACREF2IfwdScaler))
#define LUW_W5SM_LY		(uint16_t)(0.896296 * (LEDForwardCurrent/DACREF2IfwdScaler))

const uint16_t tab_bin[5] = 
{
	LUW_W5SM_KX, 
	LUW_W5SM_KY, 
	LUW_W5SM_KZ, 
	LUW_W5SM_LX, 
	LUW_W5SM_LY
};
