/*
    (c) 2016 Microchip Technology Inc. and its subsidiaries. You may use this
    software and any derivatives exclusively with Microchip products.

    THIS SOFTWARE IS SUPPLIED BY MICROCHIP "AS IS". NO WARRANTIES, WHETHER
    EXPRESS, IMPLIED OR STATUTORY, APPLY TO THIS SOFTWARE, INCLUDING ANY IMPLIED
    WARRANTIES OF NON-INFRINGEMENT, MERCHANTABILITY, AND FITNESS FOR A
    PARTICULAR PURPOSE, OR ITS INTERACTION WITH MICROCHIP PRODUCTS, COMBINATION
    WITH ANY OTHER PRODUCTS, OR USE IN ANY APPLICATION.

    IN NO EVENT WILL MICROCHIP BE LIABLE FOR ANY INDIRECT, SPECIAL, PUNITIVE,
    INCIDENTAL OR CONSEQUENTIAL LOSS, DAMAGE, COST OR EXPENSE OF ANY KIND
    WHATSOEVER RELATED TO THE SOFTWARE, HOWEVER CAUSED, EVEN IF MICROCHIP HAS
    BEEN ADVISED OF THE POSSIBILITY OR THE DAMAGES ARE FORESEEABLE. TO THE
    FULLEST EXTENT ALLOWED BY LAW, MICROCHIP'S TOTAL LIABILITY ON ALL CLAIMS IN
    ANY WAY RELATED TO THIS SOFTWARE WILL NOT EXCEED THE AMOUNT OF FEES, IF ANY,
    THAT YOU HAVE PAID DIRECTLY TO MICROCHIP FOR THIS SOFTWARE.

    MICROCHIP PROVIDES THIS SOFTWARE CONDITIONALLY UPON YOUR ACCEPTANCE OF THESE
    TERMS.
*/

/*@@ntc.h
 * *****************************************************************************
 * Summary:
 * Provides a scaled lookup table for a 10k NTC
 *
 * Description:
 * This look-up table has been created for a 10k NTC-type. This NTC is connected
 * in series to a 1k refrence resistor to form a voltage divider. The bias voltage
 * of this votlage divider is VDD of the controller.
 * Each index of this look-up table provides a temperature in [C] for each 
 * value of a 10-bit ADC (Vref = VDD). Thus the ADC reading becomes the table
 * index without any further calculation and can easily be migrated without further
 * scaling to specific supply volgates respectively.
 *
 * The temperatures given here are scaled to single digit C fitting into a 
 * 8bit integer number
 * 
 * Implementation:
 *
 * Add array int8_t tab_ntc[]; to the global variables declarations.
 * 
 * *****************************************************************************
 */
#include <stdint.h>

const int8_t tab_ntc[1024] = 
{
    125, 125, 125, 125, 125, 125, 125, 125, 
    125, 125, 125, 125, 125, 125, 125, 125, 
    125, 125, 125, 125, 125, 125, 125, 125, 
    125, 125, 125, 125, 125, 125, 125, 125, 
    125, 125, 125, 125, 125, 125, 125, 125, 
    125, 125, 125, 125, 125, 125, 125, 125, 
    125, 125, 125, 125, 124, 123, 122, 121, 
    121, 120, 119, 118, 118, 117, 116, 116, 
    115, 114, 114, 113, 112, 112, 111, 111, 
    110, 109, 109, 108, 107, 107, 106, 106, 
    105, 105, 104, 104, 103, 103, 102, 102, 
    101, 101, 100, 100, 99, 99, 98, 98, 
    97, 97, 96, 96, 96, 95, 95, 94, 
    94, 94, 93, 93, 92, 92, 92, 91, 
    91, 91, 90, 90, 90, 89, 89, 89, 
    88, 88, 88, 87, 87, 87, 86, 86, 
    86, 85, 85, 85, 84, 84, 84, 83, 
    83, 83, 82, 82, 82, 81, 81, 81, 
    81, 80, 80, 80, 79, 79, 79, 79, 
    78, 78, 78, 78, 77, 77, 77, 77, 
    76, 76, 76, 76, 75, 75, 75, 75, 
    74, 74, 74, 74, 73, 73, 73, 73, 
    72, 72, 72, 72, 71, 71, 71, 71, 
    71, 70, 70, 70, 70, 69, 69, 69, 
    69, 69, 68, 68, 68, 68, 68, 67, 
    67, 67, 67, 67, 66, 66, 66, 66, 
    66, 65, 65, 65, 65, 65, 64, 64, 
    64, 64, 64, 63, 63, 63, 63, 63, 
    63, 62, 62, 62, 62, 62, 61, 61, 
    61, 61, 61, 61, 60, 60, 60, 60, 
    60, 60, 59, 59, 59, 59, 59, 59, 
    58, 58, 58, 58, 58, 58, 57, 57, 
    57, 57, 57, 57, 56, 56, 56, 56, 
    56, 56, 55, 55, 55, 55, 55, 55, 
    54, 54, 54, 54, 54, 54, 54, 53, 
    53, 53, 53, 53, 53, 52, 52, 52, 
    52, 52, 52, 52, 51, 51, 51, 51, 
    51, 51, 51, 50, 50, 50, 50, 50, 
    50, 50, 49, 49, 49, 49, 49, 49, 
    49, 48, 48, 48, 48, 48, 48, 48, 
    47, 47, 47, 47, 47, 47, 47, 46, 
    46, 46, 46, 46, 46, 46, 46, 45, 
    45, 45, 45, 45, 45, 45, 45, 44, 
    44, 44, 44, 44, 44, 44, 44, 43, 
    43, 43, 43, 43, 43, 43, 43, 42, 
    42, 42, 42, 42, 42, 42, 42, 41, 
    41, 41, 41, 41, 41, 41, 41, 40, 
    40, 40, 40, 40, 40, 40, 40, 39, 
    39, 39, 39, 39, 39, 39, 39, 39, 
    38, 38, 38, 38, 38, 38, 38, 38, 
    37, 37, 37, 37, 37, 37, 37, 37, 
    37, 36, 36, 36, 36, 36, 36, 36, 
    36, 36, 35, 35, 35, 35, 35, 35, 
    35, 35, 35, 34, 34, 34, 34, 34, 
    34, 34, 34, 34, 33, 33, 33, 33, 
    33, 33, 33, 33, 33, 32, 32, 32, 
    32, 32, 32, 32, 32, 32, 31, 31, 
    31, 31, 31, 31, 31, 31, 31, 31, 
    30, 30, 30, 30, 30, 30, 30, 30, 
    30, 29, 29, 29, 29, 29, 29, 29, 
    29, 29, 29, 28, 28, 28, 28, 28, 
    28, 28, 28, 28, 27, 27, 27, 27, 
    27, 27, 27, 27, 27, 27, 26, 26, 
    26, 26, 26, 26, 26, 26, 26, 26, 
    25, 25, 25, 25, 25, 25, 25, 25, 
    25, 24, 24, 24, 24, 24, 24, 24, 
    24, 24, 24, 23, 23, 23, 23, 23, 
    23, 23, 23, 23, 23, 22, 22, 22, 
    22, 22, 22, 22, 22, 22, 22, 21, 
    21, 21, 21, 21, 21, 21, 21, 21, 
    21, 20, 20, 20, 20, 20, 20, 20, 
    20, 20, 19, 19, 19, 19, 19, 19, 
    19, 19, 19, 19, 18, 18, 18, 18, 
    18, 18, 18, 18, 18, 18, 17, 17, 
    17, 17, 17, 17, 17, 17, 17, 17, 
    16, 16, 16, 16, 16, 16, 16, 16, 
    16, 16, 15, 15, 15, 15, 15, 15, 
    15, 15, 15, 14, 14, 14, 14, 14, 
    14, 14, 14, 14, 14, 13, 13, 13, 
    13, 13, 13, 13, 13, 13, 13, 12, 
    12, 12, 12, 12, 12, 12, 12, 12, 
    12, 11, 11, 11, 11, 11, 11, 11, 
    11, 11, 11, 10, 10, 10, 10, 10, 
    10, 10, 10, 10, 9, 9, 9, 9, 
    9, 9, 9, 9, 9, 9, 8, 8, 
    8, 8, 8, 8, 8, 8, 8, 7, 
    7, 7, 7, 7, 7, 7, 7, 7, 
    7, 6, 6, 6, 6, 6, 6, 6, 
    6, 6, 6, 5, 5, 5, 5, 5, 
    5, 5, 5, 5, 4, 4, 4, 4, 
    4, 4, 4, 4, 4, 3, 3, 3, 
    3, 3, 3, 3, 3, 3, 2, 2, 
    2, 2, 2, 2, 2, 2, 2, 1, 
    1, 1, 1, 1, 1, 1, 1, 1, 
    0, 0, 0, 0, 0, 0, 0, 0, 
    -1, -1, -1, -1, -1, -1, -1, -1, 
    -1, -2, -2, -2, -2, -2, -2, -2, 
    -2, -3, -3, -3, -3, -3, -3, -3, 
    -3, -3, -4, -4, -4, -4, -4, -4, 
    -4, -4, -4, -5, -5, -5, -5, -5, 
    -5, -5, -6, -6, -6, -6, -6, -6, 
    -6, -6, -7, -7, -7, -7, -7, -7, 
    -7, -8, -8, -8, -8, -8, -8, -8, 
    -8, -9, -9, -9, -9, -9, -9, -9, 
    -9, -10, -10, -10, -10, -10, -10, -11, 
    -11, -11, -11, -11, -11, -11, -12, -12, 
    -12, -12, -12, -12, -12, -13, -13, -13, 
    -13, -13, -13, -13, -14, -14, -14, -14, 
    -14, -14, -14, -15, -15, -15, -15, -15, 
    -15, -16, -16, -16, -16, -16, -16, -17, 
    -17, -17, -17, -17, -17, -18, -18, -18, 
    -18, -18, -18, -19, -19, -19, -19, -19, 
    -19, -20, -20, -20, -20, -20, -21, -21, 
    -21, -21, -21, -22, -22, -22, -22, -22, 
    -23, -23, -23, -23, -23, -24, -24, -24, 
    -24, -24, -25, -25, -25, -25, -26, -26, 
    -26, -26, -27, -27, -27, -27, -27, -28, 
    -28, -28, -28, -29, -29, -29, -29, -29, 
    -30, -30, -30, -31, -31, -31, -31, -32, 
    -32, -32, -33, -33, -33, -33, -34, -34, 
    -34, -34, -35, -35, -36, -36, -36, -37, 
    -37, -37, -38, -38, -38, -39, -39, -39, 
    -40, -40, -40, -40, -40, -40, -40, -40, 
    -40, -40, -40, -40, -40, -40, -40, -40, 
    -40, -40, -40, -40, -40, -40, -40, -40, 
    -40, -40, -40, -40, -40, -40, -40, -40, 
    -40, -40, -40, -40, -40, -40, -40, -40, 
    -40, -40, -40, -40, -40, -40, -100, -100
};

