/*
    (c) 2016 Microchip Technology Inc. and its subsidiaries. You may use this
    software and any derivatives exclusively with Microchip products.

    THIS SOFTWARE IS SUPPLIED BY MICROCHIP "AS IS". NO WARRANTIES, WHETHER
    EXPRESS, IMPLIED OR STATUTORY, APPLY TO THIS SOFTWARE, INCLUDING ANY IMPLIED
    WARRANTIES OF NON-INFRINGEMENT, MERCHANTABILITY, AND FITNESS FOR A
    PARTICULAR PURPOSE, OR ITS INTERACTION WITH MICROCHIP PRODUCTS, COMBINATION
    WITH ANY OTHER PRODUCTS, OR USE IN ANY APPLICATION.

    IN NO EVENT WILL MICROCHIP BE LIABLE FOR ANY INDIRECT, SPECIAL, PUNITIVE,
    INCIDENTAL OR CONSEQUENTIAL LOSS, DAMAGE, COST OR EXPENSE OF ANY KIND
    WHATSOEVER RELATED TO THE SOFTWARE, HOWEVER CAUSED, EVEN IF MICROCHIP HAS
    BEEN ADVISED OF THE POSSIBILITY OR THE DAMAGES ARE FORESEEABLE. TO THE
    FULLEST EXTENT ALLOWED BY LAW, MICROCHIP'S TOTAL LIABILITY ON ALL CLAIMS IN
    ANY WAY RELATED TO THIS SOFTWARE WILL NOT EXCEED THE AMOUNT OF FEES, IF ANY,
    THAT YOU HAVE PAID DIRECTLY TO MICROCHIP FOR THIS SOFTWARE.

    MICROCHIP PROVIDES THIS SOFTWARE CONDITIONALLY UPON YOUR ACCEPTANCE OF THESE
    TERMS.
*/

#include <stdint.h>

/*@@tab_weber_fechner.c
 * *****************************************************************************
 * Summary:
 * Provides a lookup table for translating 6-bit linear PWM dimming duty ratios
 * into a non-linear ergonomic Weber-Fechner characteristic
 *
 * Description:
 * This look-up table has been created to support 6-bit PWM dimming schemes.
 * As the human eye is getting less sensitive with brightness, the Weber-Fechner
 * sensitivity scale was used to translate linear on-times across the 6-bit range
 * into a non-linear on-time characteristic
 *
 * *****************************************************************************
 */

const int16_t tab_weber_fechner[64] = 
{
0	,
172	,
185	,
199	,
214	,
230	,
248	,
266	,
287	,
308	,
332	,
357	,
384	,
413	,
445	,
478	,
515	,
554	,
596	,
641	,
690	,
742	,
798	,
859	,
924	,
994	,
1070	,
1151	,
1238	,
1332	,
1433	,
1542	,
1659	,
1785	,
1920	,
2066	,
2223	,
2391	,
2573	,
2768	,
2978	,
3204	,
3447	,
3708	,
3989	,
4292	,
4617	,
4968	,
5344	,
5750	,
6186	,
6655	,
7160	,
7702	,
8287	,
8915	,
9591	,
10319	,
11101	,
11943	,
12849	,
13823	,
14872	,
16000	
};
