/*
    (c) 2016 Microchip Technology Inc. and its subsidiaries. You may use this
    software and any derivatives exclusively with Microchip products.

    THIS SOFTWARE IS SUPPLIED BY MICROCHIP "AS IS". NO WARRANTIES, WHETHER
    EXPRESS, IMPLIED OR STATUTORY, APPLY TO THIS SOFTWARE, INCLUDING ANY IMPLIED
    WARRANTIES OF NON-INFRINGEMENT, MERCHANTABILITY, AND FITNESS FOR A
    PARTICULAR PURPOSE, OR ITS INTERACTION WITH MICROCHIP PRODUCTS, COMBINATION
    WITH ANY OTHER PRODUCTS, OR USE IN ANY APPLICATION.

    IN NO EVENT WILL MICROCHIP BE LIABLE FOR ANY INDIRECT, SPECIAL, PUNITIVE,
    INCIDENTAL OR CONSEQUENTIAL LOSS, DAMAGE, COST OR EXPENSE OF ANY KIND
    WHATSOEVER RELATED TO THE SOFTWARE, HOWEVER CAUSED, EVEN IF MICROCHIP HAS
    BEEN ADVISED OF THE POSSIBILITY OR THE DAMAGES ARE FORESEEABLE. TO THE
    FULLEST EXTENT ALLOWED BY LAW, MICROCHIP'S TOTAL LIABILITY ON ALL CLAIMS IN
    ANY WAY RELATED TO THIS SOFTWARE WILL NOT EXCEED THE AMOUNT OF FEES, IF ANY,
    THAT YOU HAVE PAID DIRECTLY TO MICROCHIP FOR THIS SOFTWARE.

    MICROCHIP PROVIDES THIS SOFTWARE CONDITIONALLY UPON YOUR ACCEPTANCE OF THESE
    TERMS.
*/

#include <xc.h>
#include <stdint.h>
#include "globals.h"
#include "mcc.h"

//------------------------------------------------------------------------------
// Idle Task = Do nothing
//------------------------------------------------------------------------------

void task_Idle ( void )
{
	/* Do Nothing*/
	return;
}

//------------------------------------------------------------------------------
// Input under voltage data acquisition & test
//------------------------------------------------------------------------------

void task_CheckInputUnderVoltage ( void )
{

	// get most recent input voltage
	sepic.input_voltage = ADC_GetConversion(adinInputVoltage);
  UARTsend.send[1] = (uint8_t)(sepic.input_voltage >> 2);

	// Check for Under Voltage Lock Out (UVLO) conditions
	if ( sepic.input_voltage <= fault_controller.fltSettingsUVLO.trip )
	{
		fault_controller.fltSettingsUVLO.counter++; // Increment counter value
	}
	else if ( sepic.input_voltage > fault_controller.fltSettingsUVLO.release )
	{
		fault_controller.fltSettingsUVLO.counter = 0; // Reset counter value
	}

	if ( fault_controller.fltSettingsUVLO.counter >= fault_controller.fltSettingsUVLO.threshold ) // Check fault counter
	{
		fault_controller.fltSettingsUVLO.counter = fault_controller.fltSettingsUVLO.threshold; // Clamp counter value
		fault_controller.status.flt_uvlo_shutdown = 1; // Set fault flag
		fault_controller.status.flt_fault_detect = 1;

		FaultShutDown();	// switch off converter immediately
	}

	return;
	
}
//------------------------------------------------------------------------------
// Input over voltage data acquisition & test
//------------------------------------------------------------------------------

void task_CheckInputOverVoltage ( void )
{
	
	// Check for Over Voltage Lock Out (OVLO) conditions
	if ( sepic.input_voltage >= fault_controller.fltSettingsOVLO.trip )
	{
		fault_controller.fltSettingsOVLO.counter++; // Increment counter value
	}
	else if ( sepic.input_voltage < fault_controller.fltSettingsOVLO.release )
	{
		fault_controller.fltSettingsOVLO.counter = 0; // Reset counter value
	}

	if ( fault_controller.fltSettingsOVLO.counter >= fault_controller.fltSettingsOVLO.threshold ) // Check fault counter
	{
		fault_controller.fltSettingsOVLO.counter = fault_controller.fltSettingsOVLO.threshold; // Clamp counter value
		fault_controller.status.flt_ovlo_shutdown = 1; // Set fault flag
		fault_controller.status.flt_fault_detect = 1;

		FaultShutDown();	// switch off converter immediately
	}

	return;

}

//------------------------------------------------------------------------------
// Over temperature warning data acquisition & test
//------------------------------------------------------------------------------

void task_CheckTemperatureWarning ( void )
{
	uint16_t i_read = 0;

	i_read = ADC_GetConversion(adinTemperature); // Read NTC voltage
	sepic.led_temperature = tab_ntc[i_read];
  UARTsend.send[2] = sepic.led_temperature;


	// Check for Over Temperature Warning conditions
	if ( sepic.led_temperature >= fault_controller.fltSettingsOTW.trip )
	{
		fault_controller.fltSettingsOTW.counter++; // Increment counter value
	}
	else if ( sepic.led_temperature < fault_controller.fltSettingsOTW.release )
	{
		fault_controller.fltSettingsOTW.counter = 0; // Reset counter value
	}

	if ( fault_controller.fltSettingsOTW.counter >= fault_controller.fltSettingsOTW.threshold ) // Check fault counter
	{
		fault_controller.fltSettingsOTW.counter = fault_controller.fltSettingsOTW.threshold; // Clamp counter value
		fault_controller.status.flt_ot_warning = 1; // Set fault flag
		sepic.status.temp_derating_active = 1;
	}
	else
	{
		sepic.status.temp_derating_active = 0;
	}

	return;
}

//------------------------------------------------------------------------------
// Over temperature protection data acquisition & test
//------------------------------------------------------------------------------

void task_CheckTemperatureProtection ( void )
{
	// Check for Over Temperature Protection conditions
	if ( sepic.led_temperature >= fault_controller.fltSettingsOTP.trip )
	{
		fault_controller.fltSettingsOTP.counter++; // Increment counter value
	}
	else if ( sepic.led_temperature < fault_controller.fltSettingsOTP.release )
	{
		fault_controller.fltSettingsOTP.counter = 0; // Reset counter value
	}

	if ( fault_controller.fltSettingsOTP.counter >= fault_controller.fltSettingsOTP.threshold ) // Check fault counter
	{
		fault_controller.fltSettingsOTP.counter = fault_controller.fltSettingsOTP.threshold; // Clamp counter value
		fault_controller.status.flt_otp_shutdown = 1; // Set fault flag
		fault_controller.status.flt_fault_detect = 1;

		sepic.status.global_fault = 1;	// Set global fault flag
		FaultShutDown();	// switch off converter immediately
	}

	// Check for broken cable connection between LED driver and load
	if ( sepic.led_temperature == -100 )
	{
		fault_controller.status.flt_open_circuit = 1;
		fault_controller.status.flt_fault_detect = 1;

		FaultShutDown();	// switch off converter immediately
	}

	return;
}

//------------------------------------------------------------------------------
// Set new dimming value
//------------------------------------------------------------------------------

void task_SetDimmingDutyRatio ( void )
{
  // Dimming value clamping
	if ( sepic.led_dim_ratio >= regDimmingPWMPeriod )
	{
		sepic.led_dim_ratio = regDimmingPWMPeriod + 1;
	}

	// Set new dimming value

	if ( regDimmingPWMDutyCycle != sepic.led_dim_ratio )
	{
		regDimmingPWMDutyCycle = sepic.led_dim_ratio;
		regDimmingPWM_DC_LDA = 1;
	}
 
	return;
}

//------------------------------------------------------------------------------
// Set new dimming value
//------------------------------------------------------------------------------

void task_SetForwardCurrentRefrence ( void )
{
	uint16_t reg_dum = 0;

	// Read recent DAC value
  reg_dum = DAC1REF;
	
	// Skip current reference adjustment
	if ( ( reg_dum == sepic.led_forward_current ) || ( sepic.status.global_fault ) )
	{
		return;							 // No change required => Exit 
	}
	else if(!sepic.status.phase_in)
	{
    DAC1_Load10bitInputData(sepic.led_forward_current);
	}
	else
	{
	}	

	return;
}

//------------------------------------------------------------------------------
// Output voltage data acquisition & test
//------------------------------------------------------------------------------

void task_CheckOutputVoltage ( void )
{
	sepic.output_voltage = ADC_GetConversion(adinOutputVoltage);
  UARTsend.send[3] = (uint8_t)(sepic.output_voltage >> 2);

	// Check for Hardware Output Over Voltage Shut Down (OVP)
	if ( fault_controller.status.flt_ovp_shutdown )
	{
		// shut Down is performed in the comparator ISR
		fault_controller.status.flt_fault_detect = 1;
	}

	return;
}

//------------------------------------------------------------------------------
// BIN resistor measurement and BIN class detection
//------------------------------------------------------------------------------

void GetBIN ( void )
{

	uint16_t binr = 0, i = 0;
	;

	if ( sepic.led_bin_class == 0 ) // Only call BIN detection once
	{

		binr = ADC_GetConversion(adinBinResistor);
		binr &= bin_class_feedback_mask;

		for ( i = 4; i > 0; i-- )
		{
			if ( tab_bin_class_feedback[i] <= binr )
			{
				// Set BIN class and exit loop 

 				sepic.led_bin_current = tab_bin[i+1];
				sepic.led_bin_class = ( i + 1 );
        
                sepic.led_forward_current = sepic.led_bin_current;  
                DAC1_Load10bitInputData(sepic.led_forward_current); 
        
				break;
			}
		}

	}

  return;
}

//------------------------------------------------------------------------------
// UART receive handler
// Byte0  Byte1   Byte2   Byte3
// 0xA1   LED I-H LED I-L 0x0D    LED current, value based on shunt and DAC settings 
// 0xA2   dim H   dim L   0x0D    dimming ratio from 0-100% based on PWM5 period = 16000
// 0xA3                           only for RTI
// 0xA4   0x00    0 or 1  0x0D    Byte2=0 --> linear dimming
//                                Byte2=1 --> weber fechner dimming
//------------------------------------------------------------------------------
unsigned char RecBytes[4], RecByteCounter = 0;
volatile struct UARTHandle_
{
  unsigned RecFrameReady : 1;
  unsigned : 1;
  unsigned : 1;
  unsigned : 1;
  unsigned : 1;
  unsigned : 1;
  unsigned : 1;
  unsigned : 1;
} UARTHandle;

void task_RecUart(void)
{
  if (PIR1bits.RCIF)
  {
    RecBytes[RecByteCounter++] = EUSART_Read();
    PIR1bits.RCIF = 0;
    if (RecBytes[3] == 0x0D)
    {
      RecByteCounter = 0;
      UARTHandle.RecFrameReady = 1;
      RecBytes[3] = 0x00;
    }
    else
    {
      UARTHandle.RecFrameReady = 0;
    }
  }
  if (UARTHandle.RecFrameReady)
  {
    UARTHandle.RecFrameReady = 0;
    
    if (RecBytes[0] == 0xA1)
    {
      sepic.led_forward_current = (uint16_t) (RecBytes[1] << 8) | RecBytes[2];
      task_SetForwardCurrentRefrence();
    }

    if (RecBytes[0] == 0xA2)
    {
      if(!sepic.status.WeberFechnerDimming)
      {  
        sepic.led_dim_ratio = (uint16_t) (RecBytes[1] << 8) | RecBytes[2];
      }
      else
      {
        sepic.led_dim_ratio = tab_weber_fechner[(uint16_t) (RecBytes[1] << 8) | RecBytes[2]];
      }
    }
    
    if (RecBytes[0] == 0xA4)
    {
      sepic.status.WeberFechnerDimming = RecBytes[2];
    }

  }
  
  return;
}
//------------------------------------------------------------------------------
// UART transmitt handler
// UARTsend array[0] = 0xAA
// UARTsend array[1] = input Voltage
// UARTsend array[2] = temperature
// UARTsend array[3] = output voltage
// UARTsend array[4] = sepic.status
// UARTsend array[5] = fault_controller.status
// UARTsend array[6] = Board Rev.
// UARTsend array[7] = nu BIN resistor
// UARTsend array[8] = nu LED forward current
// UARTsend array[9] = 0x0D
//------------------------------------------------------------------------------
void task_SendUart ( void )
{
//  DebugPin_WR = 1;
  UARTsend.send[4] = sepic.status.status;
  UARTsend.send[5] = fault_controller.status.status;

  if(TXSTAbits.TRMT)
  {
    EUSART_Write(UARTsend.send[UARTsend.counter++]);
  }

  if(UARTsend.counter > UARTsend.maxCount)
  {
    UARTsend.counter = 0;
  }
  
//  DebugPin_WR = 0;
	
  return;
}

void InitUARTsend (void)
{
  uint8_t i_;

  UARTsend.maxCount = 9;
  UARTsend.send[0] = 0xAA;
  UARTsend.send[UARTsend.maxCount] = 0x0D;
  UARTsend.SendTaskCounter = 0;
  
  UARTsend.counter = 0;
 
  for(i_=1; i_< UARTsend.maxCount; i_++)
  {  
    UARTsend.send[i_] = i_;  
  }
  
  UARTsend.send[6] = 0xB1; //Board Revision
  
  return;
}
